@@ -1,7 +1,7 @@
 import cv2
 from PIL import Image,ImageDraw,ImageFont
 import numpy as np
-from matplotlib import pyplot as plt
+
 import os,shutil,glob
 
 #########################Fonts###########################
@@ -272,10 +272,10 @@ def polygon_mask_old(polygons,size):
     print(mask.shape)
     print(mask.sum())
     return mask
-def polygon_mask(polygons,size):
+def polygon_mask(polygons,size,fillvalue=255):
     mask=np.zeros(size[::-1], dtype=np.uint8)
     polygons=np.array(polygons,dtype=np.int32)
-    cv2.fillPoly(mask, polygons, 255)
+    cv2.fillPoly(mask, polygons, fillvalue)
     return mask
 def inpaint_polygon_areas(img,polygons):
     h,w=img.shape[:2]
@@ -313,6 +313,7 @@ def cv2imshow(x,title='cv2 image'):
     cv2.imshow(title,x)
     cv2.waitKey(0)
 def pltimshow(x,*args,**kwargs):
+    from matplotlib import pyplot as plt
     x=cv2img(x)
     plt.imshow(x,*args,**kwargs)
     plt.show()
