@@ -9,7 +9,7 @@ def _is_pil_image(img):
 
 
 def rgb_to_hsv(rgb):
-    import numpy as np
+
     # Translated from source of colorsys.rgb_to_hsv
     # r,g,b should be a numpy arrays with values between 0 and 255
     # rgb_to_hsv returns an array of floats between 0.0 and 1.0.
@@ -36,7 +36,7 @@ def rgb_to_hsv(rgb):
 
 
 def hsv_to_rgb(hsv):
-    import numpy as np
+
     # Translated from source of colorsys.hsv_to_rgb
     # h,s should be a numpy arrays with values between 0.0 and 1.0
     # v should be a numpy array with values between 0.0 and 255.0
@@ -58,7 +58,7 @@ def hsv_to_rgb(hsv):
 
 
 # def adjust_hue_np(img, delta):
-#     import numpy as np
+#
 #     img = np.array(img)
 #     hsv = rgb_to_hsv(img)
 #     hsv[..., 0] += delta
@@ -67,7 +67,7 @@ def hsv_to_rgb(hsv):
 #     img = Image.fromarray(rgb.astype(np.uint8))
 #     return img
 # def adjust_saturation_np(img, factor):
-#     import numpy as np
+#
 #     img = np.array(img)
 #     hsv = rgb_to_hsv(img)
 #     hsv[..., 1] *= factor
@@ -93,7 +93,7 @@ def adjust_sharpness(img, factor):
 
 
 def adjust_hsv(img, h_delta=None, s_factor=None, v_factor=None):
-    import numpy as np
+
     '''hue:0~360,s:0~1,v:0~255'''
     rgb = np.array(img)
     if h_delta is not None:
@@ -655,7 +655,7 @@ def equalize(img, mask=None):
 # 高斯模糊，运动模糊，高斯白噪声，椒盐噪声，poison，
 
 def gaussian_noise(img, var=0.1):
-    import numpy as np
+
     img = np.array(img)
     mean = 0
     sigma = var ** 0.5
@@ -666,7 +666,7 @@ def gaussian_noise(img, var=0.1):
 
 
 def sp_noise(img, amount=0.004):
-    import numpy as np
+
     img = np.array(img)
     s_vs_p = 0.5
     out = np.copy(img)
@@ -688,7 +688,7 @@ def sp_noise(img, amount=0.004):
 
 
 def poisson_noise(img):
-    import numpy as np
+
     img = np.array(img)
     vals = len(np.unique(img))
     vals = 2 ** np.ceil(np.log2(vals))
@@ -698,7 +698,7 @@ def poisson_noise(img):
 
 
 def speckle_noise(img):
-    import numpy as np
+
     img = np.array(img)
     gauss = np.random.randn(*img.shape)
     img = img + img * gauss
